@@ -5,7 +5,7 @@ from configparser import ConfigParser, MissingSectionHeaderError
 import os
 import cv2
 import numpy as np
-from drop_bp_cords import getBpHeaders
+from simba.drop_bp_cords import getBpHeaders
 
 def plotHeatMap(inifile, animalbp1, mmSize, noIncrements, secIncrements, colorPalette, lastImageOnlyBol, targetBehav):
     config = ConfigParser()
